==> xulrunner-1.8.en-US.linux-i686.tar.gz: org/mozilla/xpcom/nsIDOMSVGSVGElement.java <==
/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIDOMSVGSVGElement">
 **/

package org.mozilla.xpcom;

public interface nsIDOMSVGSVGElement extends nsIDOMSVGElement
{
  String NS_IDOMSVGSVGELEMENT_IID =
    "{67b8f41e-3577-4c8a-b1de-bef51186fe08}";

  nsIDOMSVGAnimatedLength getX();

  nsIDOMSVGAnimatedLength getY();

  nsIDOMSVGAnimatedLength getWidth();

  nsIDOMSVGAnimatedLength getHeight();

  String getContentScriptType();

  void setContentScriptType(String arg1);

  String getContentStyleType();

  void setContentStyleType(String arg1);

  nsIDOMSVGRect getViewport();

  float getPixelUnitToMillimeterX();

  float getPixelUnitToMillimeterY();

  float getScreenPixelToMillimeterX();

  float getScreenPixelToMillimeterY();

  boolean getUseCurrentView();

  void setUseCurrentView(boolean arg1);

  nsISupports getCurrentView();

  float getCurrentScale();

  void setCurrentScale(float arg1);

  nsIDOMSVGPoint getCurrentTranslate();

  long suspendRedraw(long arg1);

  void unsuspendRedraw(long arg1);

  void unsuspendRedrawAll();

  void forceRedraw();

  void pauseAnimations();

  void unpauseAnimations();

  boolean animationsPaused();

  float getCurrentTime();

  void setCurrentTime(float arg1);

  nsIDOMNodeList getIntersectionList(nsIDOMSVGRect arg1, nsIDOMSVGElement arg2);

  nsIDOMNodeList getEnclosureList(nsIDOMSVGRect arg1, nsIDOMSVGElement arg2);

  boolean checkIntersection(nsIDOMSVGElement arg1, nsIDOMSVGRect arg2);

  boolean checkEnclosure(nsIDOMSVGElement arg1, nsIDOMSVGRect arg2);

  void deSelectAll();

  nsIDOMSVGNumber createSVGNumber();

  nsIDOMSVGLength createSVGLength();

  nsIDOMSVGAngle createSVGAngle();

  nsIDOMSVGPoint createSVGPoint();

  nsIDOMSVGMatrix createSVGMatrix();

  nsIDOMSVGRect createSVGRect();

  nsIDOMSVGTransform createSVGTransform();

  nsIDOMSVGTransform createSVGTransformFromMatrix(nsIDOMSVGMatrix arg1);

  String createSVGString();

  nsIDOMElement getElementById(String arg1);

  nsIDOMSVGMatrix getViewboxToViewportTransform();

}

==> xulrunner-1.8.1b1.en-US.linux-i686.tar.gz: org/mozilla/xpcom/nsIDOMSVGSVGElement.java <==
/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIDOMSVGSVGElement">
 **/

package org.mozilla.xpcom;

public interface nsIDOMSVGSVGElement extends nsIDOMSVGElement
{
  String NS_IDOMSVGSVGELEMENT_IID =
    "{67b8f41e-3577-4c8a-b1de-bef51186fe08}";

  nsIDOMSVGAnimatedLength getX();

  nsIDOMSVGAnimatedLength getY();

  nsIDOMSVGAnimatedLength getWidth();

  nsIDOMSVGAnimatedLength getHeight();

  String getContentScriptType();

  void setContentScriptType(String arg1);

  String getContentStyleType();

  void setContentStyleType(String arg1);

  nsIDOMSVGRect getViewport();

  float getPixelUnitToMillimeterX();

  float getPixelUnitToMillimeterY();

  float getScreenPixelToMillimeterX();

  float getScreenPixelToMillimeterY();

  boolean getUseCurrentView();

  void setUseCurrentView(boolean arg1);

  nsIDOMSVGViewSpec getCurrentView();

  float getCurrentScale();

  void setCurrentScale(float arg1);

  nsIDOMSVGPoint getCurrentTranslate();

  long suspendRedraw(long arg1);

  void unsuspendRedraw(long arg1);

  void unsuspendRedrawAll();

  void forceRedraw();

  void pauseAnimations();

  void unpauseAnimations();

  boolean animationsPaused();

  float getCurrentTime();

  void setCurrentTime(float arg1);

  nsIDOMNodeList getIntersectionList(nsIDOMSVGRect arg1, nsIDOMSVGElement arg2);

  nsIDOMNodeList getEnclosureList(nsIDOMSVGRect arg1, nsIDOMSVGElement arg2);

  boolean checkIntersection(nsIDOMSVGElement arg1, nsIDOMSVGRect arg2);

  boolean checkEnclosure(nsIDOMSVGElement arg1, nsIDOMSVGRect arg2);

  void deSelectAll();

  nsIDOMSVGNumber createSVGNumber();

  nsIDOMSVGLength createSVGLength();

  nsIDOMSVGAngle createSVGAngle();

  nsIDOMSVGPoint createSVGPoint();

  nsIDOMSVGMatrix createSVGMatrix();

  nsIDOMSVGRect createSVGRect();

  nsIDOMSVGTransform createSVGTransform();

  nsIDOMSVGTransform createSVGTransformFromMatrix(nsIDOMSVGMatrix arg1);

  String createSVGString();

  nsIDOMElement getElementById(String arg1);

  nsIDOMSVGMatrix getViewboxToViewportTransform();

}
